#
# spec file for package nrpe
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define nnmmsg logger -t %{name}/rpm
%define nrpeport 5666
%if ! %{defined _rundir}
  %define _rundir %{_localstatedir}/run
%endif
%{!?_tmpfilesdir:%global _tmpfilesdir %{_prefix}/lib/tmpfiles.d}
%if 0%{?suse_version} >= 1210 || 0%{?centos_version} >= 600
  %bcond_without systemd
%else
  %bcond_with systemd
%endif
%if 0%{?suse_version} >= 01500
  %bcond_without firewalld
%else
  %bcond_with firewalld
%endif
%if 0%{?suse_version} >= 01500
%bcond_without reproducable
%else
%bcond_with reproducable
%endif
Name:           nrpe
Version:        4.0.3
Release:        bp156.4.43
Summary:        Nagios Remote Plug-In Executor
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            http://www.nagios.org/
Source0:        nrpe-%{version}.tar.bz2
Source1:        nrpe.init
Source2:        nrpe-rpmlintrc
Source3:        nrpe-SuSEfirewall2
Source4:        nrpe.8
Source5:        check_nrpe.cfg
Source10:       README.SUSE
Source11:       README.SUSE.systemd-addon
Source12:       usr.sbin.nrpe
Source13:       nrpe.xml
Source14:       nrpe-dh.h
# PATCH-FIX-UPSTREAM improve help output of nrpe and check_nrpe
Patch2:         nrpe-improved_help.patch
# PATCH-FIX-openSUSE fix pathnames for nrpe_check_control command
Patch4:         nrpe_check_control.patch
# PATCH-FIX-UPSTREAM using implicit definitions of functions
Patch5:         nrpe-implicit_declaration.patch
# PATCH-FIX-openSUSE patch used to NOT re-calculate dh.h parameters (for reproducable builds)
Patch6:         nrpe-static_dh_parameters.patch
# PATCH-FIX-openSUSE disable chkconfig call in Makefile
Patch7:         nrpe-disable-chkconfig_in_Makefile.patch
# PATCH-FIX-UPSTREAM this fills up the logs on the clients without real need
Patch8:         nrpe-4.0.4-silence_wrong_package_version_messages.patch
BuildRequires:  monitoring-plugins-common
BuildRequires:  nagios-rpm-macros
Requires(pre):  grep
Requires(pre):  sed
Provides:       nagios-nrpe = %{version}
Obsoletes:      nagios-nrpe < 2.14
Provides:       nagios-nrpe-client = %{version}
Obsoletes:      nagios-nrpe-client < %{version}
PreReq:         %fillup_prereq
%if 0%{?suse_version} < 1200
PreReq:         %insserv_prereq
PreReq:         /bin/logger
%else
Requires(pre):         %{_bindir}/logger
%endif
Requires(pre):  netcfg
Requires(pre):  pwdutils
%if 0%{?suse_version} > 1130
%if 0%{?suse_version} <= 1230
Requires(pre):  sysvinit(network)
Requires(pre):  sysvinit(syslog)
%endif
%endif
BuildRequires:  krb5-devel
BuildRequires:  libopenssl-devel
BuildRequires:  openssl
BuildRequires:  tcpd-devel
Recommends:     inet-daemon
Recommends:     monitoring-plugins-disk
Recommends:     monitoring-plugins-load
Recommends:     monitoring-plugins-procs
Recommends:     monitoring-plugins-users
%if %{with systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
NRPE can be used to run Nagios plugins on a remote machine for
executing local checks.
This package contains the software for NRPE server.
It could be run by an inetd, or as a standalone daemon.

%package doc
Summary:        Nagios Remote Plug-In Executor documentation
Group:          Documentation/Other
Provides:       nagios-nrpe-doc = %{version}
Obsoletes:      nagios-nrpe-doc < 2.14
%if 0%{?suse_version} >= 1230
BuildArch:      noarch
%endif

%description doc
This package contains the README files, OpenOffice and PDF
documentation for the remote plugin executor (NRPE) for Nagios.

%package -n monitoring-plugins-nrpe
Summary:        NRPE plugin
Group:          System/Monitoring
Provides:       nagios-nrpe-server = %{version}-%{release}
Obsoletes:      nagios-nrpe-server < 2.14
Provides:       nagios-plugins-nrpe = %{version}-%{release}
Obsoletes:      nagios-plugins-nrpe < 2.15-%{release}
%if 0%{?suse_version} > 1020
Recommends:     monitoring_daemon
%endif

%description -n monitoring-plugins-nrpe
This package contains the plugin for the host runing the Nagios
daemon.

It is used to contact the NRPE process on remote hosts. The plugin
requests that a plugin be executed on the remote host and wait for the
NRPE process to execute the plugin and return the result.

The plugin then uses the output and return code from the plugin
execution on the remote host for its own output and return code.

%prep
%setup -q -n %{name}-%{version}
%patch2 -p1
%patch4 -p1
%patch5 -p1
%if %{with reproducable}
%patch6 -p1
install -m644 %{SOURCE14} include/dh.h
%endif
%patch7 -p1
%patch8 -p1
cp -a %{SOURCE10} .
cp -a %{SOURCE12} .
%if 0%{?suse_version} >= 1210
cat %{SOURCE11} >> README.SUSE
%endif
chmod -x contrib/README.nrpe_check_control
# increase the number of 'allowed' processes on newer systems:
sed -i "s|check_procs -w 150 -c 200|check_procs -w 350 -c 400|g" sample-config/nrpe.cfg.in
# add the new include directory
sed -i "s|#include_dir=<someotherdirectory>|#include_dir=<someotherdirectory>\ninclude_dir=%{_sysconfdir}/nrpe.d|g" sample-config/nrpe.cfg.in

%build
%configure \
    --sbindir=%{nagios_cgidir} \
    --libexecdir=%{nagios_plugindir} \
    --datadir=%{nagios_datadir} \
    --sysconfdir=%{_sysconfdir} \
    --with-pkgsysconfdir=%{_sysconfdir} \
    --localstatedir=%{nagios_logdir} \
    --exec-prefix=%{_sbindir} \
    --bindir=%{_sbindir} \
    --sbindir=%{_sbindir} \
    --with-logdir=%{nagios_logdir} \
    --with-piddir=%{_rundir}/%{name} \
    --with-pluginsdir=%{nagios_plugindir} \
    --enable-install-method=os \
    --with-dist-type=suse \
%if %{with systemd}
    --with-init-type=systemd \
%else
    --with-init-type=sysv \
%endif
    --with-inetd-type=xinetd \
    --with-log_facility=daemon \
    --with-kerberos-inc=%{_includedir} \
    --with-nagios-user=%{nagios_user} \
    --with-nagios-group=%{nagios_group} \
    --with-nrpe-user=%{nagios_user} \
    --with-nrpe-group=%{nagios_group} \
    --with-nrpe-port=%{nrpeport} \
    --enable-command-args \
    --enable-bash-command-substitution \
    --enable-ssl
make %{?_smp_mflags} all

gcc %{optflags} -o contrib/nrpe_check_control contrib/nrpe_check_control.c

%install
install -d %{buildroot}%{_sysconfdir}/xinetd.d
install -d %{buildroot}%{_rundir}/%{name}
%if %{with systemd}
install -d %{buildroot}%{_tmpfilesdir}/
install -d %{buildroot}%{_unitdir}/
%else
install -d %{buildroot}%{_sysconfdir}/init.d/
%endif
install -d %{buildroot}%{_sysconfdir}/nrpe.d
make install install-config install-inetd install-daemon install-init \
    DESTDIR=%{buildroot} \
    CGICFGDIR="%{_sysconfdir}" \
    NAGIOS_INSTALL_OPTS="" \
    INSTALL_OPTS="" \
    COMMAND_OPTS="" \
    NRPE_INSTALL_OPTS="" \
    INIT_OPTS=""

install -Dm 644 %{SOURCE4} %{buildroot}%{_mandir}/man8/nrpe.8

%if %{with systemd}
  sed -i -e "/User=/s/\(User=\).*/\1%{nagios_user}/" -e "/Group=/s/\(Group=\).*/\1%{nagios_group}/" %{buildroot}%{_unitdir}/%{name}.service
  install -Dm644 startup/default-socket %{buildroot}%{_unitdir}/%{name}.socket
  ln -s -f %{_sbindir}/service %{buildroot}%{_sbindir}/rcnrpe
%else
  %if 0%{?suse_version} <= 1230
    # openSUSE uses own nrpe init script
    rm %{buildroot}%{_sysconfdir}/init.d/nrpe
    install -Dm 755 %{SOURCE1} %{buildroot}%{_sysconfdir}/init.d/nrpe
    ln -s -f ../..%{_initddir}/nrpe %{buildroot}%{_sbindir}/rcnrpe
  %endif
%endif

%if %{without firewalld}
  # install SuSEfirewall2 script
  install -Dm644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/nrpe
%endif

# fix pid_file in nrpe.cfg
sed -i -e "s,^\(pid_file=\).*,\1%{_rundir}/%{name}/nrpe.pid," %{buildroot}/%{_sysconfdir}/nrpe.cfg

# create directory and pidfile (package them as ghost)
%if 0%{?suse_version} <= 1230
mkdir -p %{buildroot}%{_rundir}/%{name}
touch %{buildroot}%{_rundir}/%{name}/nrpe.pid
%endif

# create home directory of nagios user
mkdir -p %{buildroot}%{nagios_localstatedir}

# create contrib plugin
install -m0755 contrib/nrpe_check_control %{buildroot}%{nagios_plugindir}/nrpe_check_control
cat > nrpe_check_control.cfg <<'EOF'
define command {
    command_name    nrpe_check_control
    command_line    %{nagios_plugindir}/nrpe_check_control $SERVICESTATE$ $SERVICESTATETYPE$ $SERVICEATTEMPT$ "$HOSTNAME$"
}
EOF
install -Dm0644 nrpe_check_control.cfg %{buildroot}%{nagios_sysconfdir}/objects/nrpe_check_control.cfg

# install simple nrpe.cfg for the Nagios server in the objects directory
install -Dm644 %{SOURCE5} %{buildroot}%{nagios_sysconfdir}/objects/check_nrpe.cfg

install -Dm755 update-cfg.pl %{buildroot}/%{_defaultdocdir}/%{name}/examples/update-cfg.pl
# ...and also the files we want in the main package
install -m644 CHANGELOG.md README.SUSE README.md usr.sbin.nrpe %{buildroot}/%{_defaultdocdir}/%{name}/
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}/local
echo "# Site-specific additions and overrides for 'usr.sbin.nrpe'" > %{buildroot}/%{_defaultdocdir}/%{name}/local/usr.sbin.nrpe
# remove the uninstall script: this is done by RPM
rm %{buildroot}/%{_sbindir}/nrpe-uninstall

%pre
# Create user and group on the system if necessary
%nagios_user_group_add
%nagios_command_user_group_add
# check if the port for nrpe is already defined in /etc/services
if grep -q %{nrpeport} %{_sysconfdir}/services ; then
    : OK - port already defined
else
    %{nnmmsg} "Adding port %{nrpeport} to %{_sysconfdir}/services"
	echo "nrpe            %{nrpeport}/tcp # Nagios nrpe" >> etc/services
fi
%if %{with systemd}
  %service_add_pre nrpe.service nrpe.socket
%endif

%preun
%if %{with systemd}
  %service_del_preun nrpe.service nrpe.socket
%else
  %stop_on_removal %{name}
%endif

%post
%if 0%{?suse_version} <= 1230
  %{fillup_and_insserv -fy %{name}}
%else
  %fillup_only %{name}
%endif

%if %{with systemd}
  %service_add_post nrpe.service nrpe.socket
  %tmpfiles_create %{_tmpfilesdir}/%{name}.conf
%endif

%pre -n monitoring-plugins-nrpe
# Create user and group on the system if necessary
%nagios_user_group_add

%triggerun -- nagios-nrpe < 2.14
STATUS='%{_localstatedir}/adm/update-scripts/nrpe'
%if %{with systemd}
  if systemctl -q is-enabled nrpe.service ; then
    echo "systemctl -q restart nrpe.service" >> "$STATUS"
  elif systemctl -q is-enabled xinetd.service ; then
    echo "systemctl -q reload xinetd.service" >> "$STATUS"
  else
    touch "$STATUS"
  fi
%else
  if [ -x %{_sysconfdir}/init.d/nrpe ]; then
    %{_sysconfdir}/init.d/nrpe status >/dev/null
    if test $? = 0; then
        echo "%{_sysconfdir}/init.d/nrpe restart" >> "$STATUS"
    else
        touch "$STATUS"
    fi
  fi
  if [ -x %{_sysconfdir}/init.d/xinetd ]; then
    %{_sysconfdir}/init.d/xinetd status >/dev/null
    if test $? = 0; then
        echo "%{_sysconfdir}/init.d/xinetd try-restart" >> "$STATUS"
    fi
  else
    touch "$STATUS"
  fi
%endif
chmod +x "$STATUS"

%triggerpostun -- nagios-nrpe < 2.14
# Move /etc/nagios/nrpe.cfg to /etc/nrpe.cfg when updating from an old version
# and inform the admin about the rename.
if test -e %{nagios_sysconfdir}/nrpe.cfg.rpmsave -a ! -e %{_sysconfdir}/nrpe.cfg.rpmnew; then
    mv %{_sysconfdir}/nrpe.cfg %{_sysconfdir}/nrpe.cfg.rpmnew
    mv %{nagios_sysconfdir}/nrpe.cfg.rpmsave %{_sysconfdir}/nrpe.cfg
    echo "# %{nagios_sysconfdir}/nrpe.cfg has been moved to %{_sysconfdir}/nrpe.cfg" > %{nagios_sysconfdir}/nrpe.cfg
    echo "# This file can be removed." >> %{nagios_sysconfdir}/nrpe.cfg
    echo "include=%{_sysconfdir}/nrpe.cfg" >> %{nagios_sysconfdir}/nrpe.cfg
fi
sed -i "s|%{nagios_sysconfdir}/nrpe.cfg|%{_sysconfdir}/nrpe.cfg|g" %{_sysconfdir}/xinetd.d/nrpe || :
%if %{without firewalld}
sed -i "s|nrpe-service|%{name}|g" %{_sysconfdir}/sysconfig/SuSEfirewall2 || :
%endif
if [ -e %{_localstatedir}/adm/update-scripts/nrpe ]; then
    /bin/sh %{_localstatedir}/adm/update-scripts/nrpe
    rm %{_localstatedir}/adm/update-scripts/nrpe
fi

%postun
%if %{with systemd}
  %service_del_postun nrpe.service nrpe.socket
 %else
  %restart_on_update nrpe
  %if 0%{?suse_version}
    %insserv_cleanup
  %endif
%endif

%files
%defattr(-,root,root)
%dir %{_defaultdocdir}/%{name}/
%dir %{_defaultdocdir}/%{name}/examples
%doc %{_defaultdocdir}/%{name}/README.SUSE
%doc %{_defaultdocdir}/%{name}/README.md
%doc %{_defaultdocdir}/%{name}/CHANGELOG.md
%doc %{_defaultdocdir}/%{name}/usr.sbin.nrpe
%dir %{_defaultdocdir}/%{name}/local
%doc %{_defaultdocdir}/%{name}/local/usr.sbin.nrpe
%doc %{_defaultdocdir}/%{name}/examples/update-cfg.pl
%{_mandir}/man8/nrpe.8%{?ext_man}
%dir %{_sysconfdir}/nrpe.d
%config(noreplace) %{_sysconfdir}/nrpe.cfg
%if 0%{?suse_version} > 1315
%dir %{_sysconfdir}/xinetd.d
%endif
%config(noreplace) %{_sysconfdir}/xinetd.d/nrpe
%if %{without firewalld}
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/nrpe
%endif
%if 0%{?suse_version} <= 1230
%ghost %{_rundir}/%{name}/nrpe.pid
%endif
%if %{with systemd}
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.socket
%{_tmpfilesdir}/%{name}.conf
%else
%{_sysconfdir}/init.d/nrpe
%endif
%ghost %dir %{_rundir}/%{name}
%attr(0755,root,root) %{_sbindir}/nrpe
%{_sbindir}/rcnrpe

%files doc
%defattr(-,root,root)
%defattr(0644,root,root,0755)
%doc CHANGELOG.md LEGAL *.md docs/*.pdf

%files -n monitoring-plugins-nrpe
%defattr(-,root,root)
%doc contrib/README.nrpe_check_control
%dir %{nagios_libdir}
%attr(0755,root,%{nagios_command_group}) %dir %{nagios_sysconfdir}
%attr(0755,root,%{nagios_command_group}) %dir %{nagios_sysconfdir}/objects
%config(noreplace) %{nagios_sysconfdir}/objects/nrpe_check_control.cfg
%config(noreplace) %{nagios_sysconfdir}/objects/check_nrpe.cfg
%{nagios_plugindir}/check_nrpe
%{nagios_plugindir}/nrpe_check_control

%changelog
* Thu Oct  7 2021 Lars Vogdt <lars@linux-schulserver.de>
- follow /bin/bash -> /usr/bin/bash in the apparmor profile
* Mon Feb 15 2021 ro@suse.de
- fix apparmor profile to allow /run as well as /var/run
* Thu Feb  4 2021 Lars Vogdt <lars@linux-schulserver.de>
- added nrpe-4.0.4-silence_wrong_package_version_messages.patch
  NRPE logs 'packet version was invalid' and 'Could not read request
  from client' if the NRPE version on the client does not match the
  one on the server side.
  This patch reduces the importance of the log entry to be just
  informal, which should silent most client logs, while it makes
  it still available for debugging.
* Fri Jan 22 2021 Lars Vogdt <lars@linux-schulserver.de>
- update to 4.0.3
  ENHANCEMENTS
  * Added TLSv1.3 and TLSv1.3+ support for systems that have it (Nigel Yong, Rahul Golam)
  * Added IPv6 ip address to list of default allow_from hosts (Troy Lea)
  * Added -D option to disable logging to syslog (Tom Griep, Sebastian Wolf)
  * Added -3 option to force check_nrpe to use NRPE v3 packets
  * OpenRC: provide a default path for nrpe.cfg (Michael Orlitzky)
  * OpenRC: Use RC_SVCNAME over a hard-coded PID file (j-licht)
  FIXES
  * Fixed nasty_metachars not being read from config file (#235) (Sebastian Wolf)
  * Fixed buffer length calculations/writing past memory boundaries
    on some systems (#227, #228) (Andreas Baumann, hariwe, Sebastian Wolf)
  * Fixed use of uninitialized variable when validating requests (#229) (hariwe, Sebastian Wolf)
  * Fixed syslog flooding with CRC-checking errors when both plugin
    and agent were updated to version 4 (Sebastian Wolf)
  * Checks for '!' now only occur inside the command buffer (Joni Eskelinen)
  * NRPE daemon is more resilient to DOS attacks (Leonid Vasiliev)
  * allowed_hosts will no longer test getaddrinfo records against the
    wrong protocol (dombenson)
  * nasty_metachars will now handle C escape sequences properly when
    specified in the config file (Sebastian Wolf)
  * Calculated packet sizes now struct padding/alignment when sending
    and receiving messages (Sebastian Wolf)
  * Buffer sizes are now checked before use in packet size calculation (Sebastian Wolf)
  * When using include_dir, individual files' errors do not prevent
    the remaining files from being read (Sebastian Wolf)
- refreshed the following patches:
  * nrpe-implicit_declaration.patch
  * nrpe-improved_help.patch
  * nrpe_check_control.patch
- renamed and refreshed the following patches/sources:
  * nrpe-3.2.1-disable-chkconfig_in_Makefile.patch
  - > nrpe-disable-chkconfig_in_Makefile.patch
  * nrpe-3.2.1-static_dh_parameters.patch
  - > nrpe-static_dh_parameters.patch
  * nrpe-3.2.1-dh.h -> nrpe-dh.h
- enhanced README.SUSE with some words about Apparmor
- added an include directive in usr.sbin.nrpe apparmor config
  and a basic local/usr.sbin.nrpe file in the docu-directory
* Tue Jul 28 2020 Thorsten Kukuk <kukuk@suse.com>
- Don't install SuSEfirewall2 service file, SuSEfirewall2 is gone
* Fri Feb 21 2020 lars@linux-schulserver.de
- nrpe.xml firewalld file is handled by firewalld package
- Leap 15.1 is suse_version 1500 (thanks, dimstar)
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Sun Mar 17 2019 Lars Vogdt <lars@linux-schulserver.de>
- Do not package nrpe.xml for Leap 15.0, as it is included in
  firewalld package there.
* Sun Feb 17 2019 lars@linux-schulserver.de
- add nrpe.xml snipplet for firewalld
- still ship nrpe snipplet for SuSEfirewalld for now
- use systemd files directly from upstream:
  + drop Requires=var-run.mount line from service file
  + drop nrpe.service
  + drop nrpe.socket
  + do not create tmpfiles.d/nrpe in spec any longer
- handle migration from /etc/nagios/nrpe.cfg to /etc/nrpe.cfg also
  for systemd case (triggerun)
- increase warn/crit level for processes to 350/400 in a default
  installation
- added patch and dh.h file to NOT re-calculate dh.h parameters
  during each build (for reproducable builds).
  Can be enable/disable by setting the 'reproducable' build
  condition. Default is: "on" for suse_version >= 15
  + nrpe-3.2.1-static_dh_parameters.patch
  + nrpe-3.2.1-dh.h
- use _rundir and _tmpfilesdir macros everywhere
- do not create nagios user/group during install on (open)SUSE
  systems and rely on the files section here instead
- rename nagios-nrpe-rpmlintrc and nagios-nrpe-SuSEfirewall2 to
  nrpe-rpmlintrc and nrpe-SuSEfirewall2
- simplify rpmlintrc
- build nrpe-doc package as noarch
- specfile cleanup & remove other distribution specials
- disable chkconfig call in Makefile on old distributions
  nrpe-3.2.1-disable-chkconfig_in_Makefile.patch
* Mon Jun  4 2018 lars@linux-schulserver.de
- only include %%{_sysconfdir}/xinetd.d on newer distributions
  (fixes submission of this package as update for SLE12-SP4
  and Leap 42.3 - boo#938906)
* Mon Mar 26 2018 dimstar@opensuse.org
- Own %%{_sysconfdir}/xinetd.d: filesystem won't own this directory
  much longer (boo#1084457).
* Fri Dec 15 2017 obs@botter.cc
- remove additional reference to removed nrpe@.service file
* Wed Dec  6 2017 lars@linux-schulserver.de
- remove unneeded nrpe@.service file
- cleanup the %%%%pre/%%%%post commands
* Tue Dec  5 2017 ro@suse.de
- update to 3.2.1:
  FIXES
  - Change seteuid error messages to warning/debug (Bryan Heden)
  - Fix segfault when no nrpe_user is specified (Stephen Smoogen, Bryan Heden)
  - Added additional strings to error messages to remove duplicates (Bryan Heden)
  - Fix nrpe.spec for rpmbuild (Bryan Heden)
  - Fix error for drop_privileges when using inetd (xalasys-luc, Bryan Heden)
- update to 3.2.0:
  ENHANCEMENTS
  - Added max_commands definition to nrpe.cfg to rate limit simultaneous fork()ed children (Bryan Heden)
  - Added -E, --stderr-to-stdout options for check_nrpe to redirect output (Bryan Heden)
  - Added support for Gentoo init (Troy Lea @box293)
  - Cleaned up code a bit, updated readmes and comments across the board (Bryan Heden)
  - Added -V, --version to nrpe and fixed the output (Bryan Heden)
  - Added different SSL error messages to be able to pinpoint where some SSL errors occured (Bryan Heden)
  - Updated logic in al parse_allowed_hosts (Bryan Heden)
  - Added builtin OpenSSL Engine support where available (Bryan Heden + @skrueger8)
  - Clean up compilation warnings (Bryan Heden)
  - Added more commented commands in nrpe.cfg (Bryan Heden)
  FIXES
  - Undefined check returns UNKNOWN (Bryan Heden)
  - Fix incompatibility with OpenSSL 1.1.0 via SECLEVEL distinction (Bryan Heden)
  - Fix ipv4 error in logfile even if address is ipv6 (Bryan Heden)
  - Fix improper valid/invalid certificate warnings (Bryan Heden)
* Tue Jul 25 2017 ro@suse.de
- change prereq from /bin/logger to /usr/bin/logger except for
  code11 and older
* Mon May 29 2017 lars@linux-schulserver.de
- update to 3.1.1:
  FIXES
  - The '--log-file=' or '-g' option is missing from the help (John Frickson)
  - check_nrpe = segfault when specifying a config file (John Frickson)
  - Alternate log file not being used soon enough (John Frickson)
  - Unable to compile v3.1.0rc1 with new SSL checks on rh5 (John Frickson)
  - Unable to compile nrpe-3.1.0 - undefined references to va_start, va_end (John Frickson)
  - Can't build on Debian Stretch, openssl 1.1.0c (John Frickson)
  - Fix build failure with -Werror=format-security (Bas Couwenberg)
  - Fixed a typo in `nrpe.spec.in` (John Frickson)
  - More detailed error logging for SSL (John Frickson)
  - Fix infinite loop when unresolvable host is in allowed_hosts (Nick / John Frickson)
- refreshed all patches
* Fri Apr 21 2017 ro@suse.de
- require inet-daemon only if suse_version is set
- call centos macros for systemd
- drop Requires=var-run.mount line from service file on centos
* Fri Apr 21 2017 ro@suse.de
- fix buildrequires for centos:
  - tcpd-devel is tcp_wrappers-devel
  - kerberos is krb5-devel
* Mon Apr 17 2017 lars@linux-schulserver.de
-update to 3.1.0:
  ENHANCEMENTS
  - Added option to nrpe.cfg.in that can override hard-coded NASTY_METACHARS (John Frickson)
  - While processing 'include_dir' statement, sort the files (Philippe Kueck / John Frickson)
  - nrpe can now write to a log file using 'log_file=' in nrpe.cfg (John Frickson)
  - check_nrpe can now write to a log file using '--log-file=' or '-g' options (John Frickson)
  FIXES
  - Added missing debugging syslog entries, and changed printf()'s to syslog()'s. (Jobst Schmalenbach)
  - Fix help output for ssl option (configure) (Ruben Kerkhof)
  - Fixes to README.SSL.md and SECURITY.md (Elan Ruusamäe)
  - Changed the 'check_load' command in nrpe.cfg.in (minusdavid)
  - Minor change to logging in check_nrpe (John Frickson)
  - Removed function `b64_decode` which wasn't being used (John Frickson)
  - check_nrpe ignores -a option when -f option is specified (John Frickson)
  - Added missing LICENSE file (John Frickson)
  - Off-by-one BO in my_system() (John Frickson)
  - Add SOURCE_DATE_EPOCH specification support for reproducible builds. (Bas Couwenberg)
  - nrpe 3.0.1 allows TLSv1 and TLSv1.1 when I configure for TLSv1.2+ (John Frickson)
  - "Remote %%s accepted a Version %%s Packet", please add to debug (John Frickson)
  - nrpe 3.0.1 segfaults when key and/or cert are broken symlinks (John Frickson)
  - Fixed a couple of typos in docs/NRPE.* files (Ludmil Meltchev)
  - Changed release date to ISO format (yyyy-mm-dd) (John Frickson)
  - Fix systemd unit description (Bas Couwenberg)
  - Add reload command to systemd service file (Bas Couwenberg)
  - fix file not found error when updating version (Sven Nierlein)
  - Spelling fixes (Josh Soref)
  - Return UNKNOWN when check_nrpe cannot communicate with nrpe and -u set (John Frickson)
  - xinetd.d parameter causes many messages in log file (John Frickson)
  - Fixes for openssl 1.1.x (Stephen Smoogen / John Frickson)
  - PATH and other environment variables not set with numeric nrpe_user (John Frickson)
- remove upstreamed patches:
  + nrpe-more_random.patch
  + nrpe-drop_privileges_before_writing_pidfile.patch
  + nrpe-3.0-Makefile_use_DESTDIR.patch
- refreshed other patches
* Wed Dec  7 2016 lars@linux-schulserver.de
- correctly call the systemd macros for all systemd units
* Sun Oct 30 2016 jengelh@inai.de
- Description updates
* Wed Oct 12 2016 ro@suse.de
- add usr.sbin.nrpe as source12 (only example for now)
- call tmpfiles_create in postinstall (bsc#1080637 and bsc#924649)
- add /run/nrpe as ghost
* Wed Aug 10 2016 lars@linux-schulserver.de
- remove patches that are fixed upstream:
  + nagios-nrpe-buffersize.patch
  + nrpe-weird_output.patch
* Fri Jul 22 2016 lars@linux-schulserver.de
- update to 3.0:
  SECURITY
- Fix for CVE-2014-2913
- Added function to clean the environment before forking.
  (John Frickson)
  ENHANCEMENTS
- Added support for optional config file to check_nrpe. With the new SSL
  parameters, the line was getting long. The config file is specified with
  - -config-file=<path> or -f <path> parameters. The config file must look
  like command line options, but the options can be on separate lines. It
  MUST NOT include --config-file (-f), --command (-c) or --args (-a). If any
  options are in both the config file and on the command line, the command line
  options are used.
- Added "nrpe-uninstall" script to the same directory nrpe get installed to
  (John Frickson)
- Added command-line option to prevent forking, since some of the init
  replacements (such as systemd, etc.) don't want daemons to fork
  (John Frickson)
- Added listen_queue_size as configuration option (Vadim Antipov, Kaspersky Lab)
- Reworked SSL/TLS. See the README.SSL.md file for full info. (John Frickson)
- Added support for version 3 variable sized packets up to 64KB. nrpe will
  accept either version from check_nrpe. check_nrpe will try to send a
  version 3 packet first, and fall back to version 2. check_nrpe can be forced
  to only send version 2 packets if the switch `-2` is used. (John Frickson)
- Added extended timeout syntax in the -t <secs>:<status> format. (ABrist)
  FIXES
- check_nrpe does not parse passed arguments correctly (John Frickson)
- NRPE should not start if cannot write pid file (John Frickson)
- Fixed out-of-bounds error (return code 255) for some failures
  (John Frickson)
- Connection Timeout and Connection Refused messages need a new line
  (Andrew Widdersheim)
- allowed_hosts doesn't work, if one of the hostnames can't be resolved
  by dns (John Frickson)
- allowed_hosts doesn't work with a hostname resolving to an IPv6 address
  (John Frickson)
- Return UNKNOWN when issues occur (Andrew Widdersheim)
- NRPE returns OK if check can't be executed (Andrew Widdersheim)
- sample configuration for check_load has crazy sample load avg
  (ernestoongaro)
- deleted patches:
  + nrpe-xinetd.patch (fixed upstream)
  + nrpe-weird_output.patch (fixed in anothr way upstream)
- refresh all other patches
- added new patch:
  + nrpe-3.0-Makefile_use_DESTDIR.patch (allow DESTDIR)
- added /usr/share/doc/packages/nrpe/examples/update-cfg.pl to allow
  easy upgrade of configuration file
* Sun Mar 29 2015 lars@linux-schulserver.de
- add missing (empty) argument to tmpfiles.d file
* Sun Jan 18 2015 lars@linux-schulserver.de
- add reload option to systemd service
- let the tmpfiles config use the tmpdir macro to define the
  place of the tmpdir
- use bcond for building with systemd support
* Wed Jul 30 2014 ro@suse.de
- use _rundir macro if available
* Wed Jul 30 2014 obs@botter.cc
- correct user and group setting in systemd service files
- remove unneeded source file nrpe.tempfiles - it is generated
  during build on-the-fly
* Wed Jul 30 2014 lars@linux-schulserver.de
- rename nagios-plugins-nrpe to monitoring-plugins-nrpe
- require the monitoring-plugins instead of nagios-plugins packages
* Fri Jul 18 2014 obs@botter.cc
- add systemd service file, and per-connection activation socket
  and service file for openSUSE >= 1210, init.d files are supplied
  for versions until 1230 including.
* Thu Jun 26 2014 lars@linux-schulserver.de
- fix group permissions of nrpe binary in n/usr/sbin
* Fri Mar  7 2014 lars@linux-schulserver.de
- rename README.SUSE according to the new policy
- fix bnc#865836: create nagios user/group for nagios-plugins-nrpe
* Thu Feb  6 2014 lars@linux-schulserver.de
- install an example check_nrpe.cfg definition in /etc/nagios/objects
* Thu Sep 26 2013 lars@linux-schulserver.de
- adapt directory ownership of /etc/nagios directories
* Thu Sep 19 2013 lars@linux-schulserver.de
- update to 2.15:
  + Added support for IPv6 (Leo Baltus, Eric Stanley)
- removed nrpe-uninitialized_variable.patch (fixed upstream)
- rebased other patches
* Mon Aug 12 2013 lars@linux-schulserver.de
- fix directory permissions for nagios sysconfdir
* Mon Aug  5 2013 ro@suse.de
- adapt owner and permissions for sysconfdir/nagios to
  main nagios package
* Sun Jan 20 2013 lars@linux-schulserver.de
- reduce runtime dependencies: just recommend the plugins that are
  configured in the default configuration, not the whole Nagios
  plugins
* Tue Jan 15 2013 lars@linux-schulserver.de
- also fix old xinetd config and SuSEFirewall2
- save the status of the old nagios-nrpe daemon via %%%%triggerun in
  /var/adm/update-scripts/nrpe and restart the service, if needed,
  after the renamed package has been installed (same, if the
  service is started via xinetd)
* Sat Dec 22 2012 lars@linux-schulserver.de
- update to 2.14:
  + Added configure option to allow bash command substitutions,
    disabled by default [bug #400] (Eric Stanley)
  + Patched to shutdown SSL connection completely (Jari Takkala)
- enable bash command substitution in binary (disabled by config)
- renamed the main package to nrpe to follow upstream
  (Provide/Obsolete the old package name)
- placed nrpe.cfg in /etc now to allow running with Icinga only
- add include directory /etc/nrpe.d to make future updates easier
- increase check_procs warning (250) and critical (300) levels
- use new rpm macro nagios_user_group_add for user-/groupadd
- refreshed patches
* Tue Nov 20 2012 dimstar@opensuse.org
- Fix useradd invocation: -o is useless without -u and newer
  versions of pwdutils/shadowutils fail on this now.
* Thu Oct 11 2012 lars@linux-schulserver.de
- the plugin can also be used with icinga
  - > recommend monitoring_daemon instead
* Sun Feb 26 2012 lars@linux-schulserver.de
- update to 2.13:
  + Applied Kaspersky Labs supplied patch for extending
    allowed_hosts (Konstantin Malov)
  + Fixed bug in allowed_hosts parsing (Eric Stanley)
- rebased patches
- simplify (and disable) nrpe-more_random.patch
- added nrpe-implicit_declaration.patch
- use macros from nagios-rpm-macros
* Mon May 30 2011 lrupp@suse.de
- specfile cleanup using spec-cleaner (add comments to patches)
* Thu Feb 10 2011 ro@suse.de
- add directory to filelist to fix build
* Mon Feb  7 2011 lars@linux-schulserver.de
- also package nrpe_check_control from contrib
* Tue Dec  7 2010 coolo@novell.com
- prereq init scripts syslog and network
* Wed Sep 22 2010 lars@linux-schulserver.de
- use /var/lib/nagios as home directory (same as nagios package)
* Sat Jul 10 2010 lars@linux-schulserver.de
- fix missing operand for dirname in init script
* Mon May 24 2010 lars@linux-schulserver.de
- add netcfg to PreReq to have /etc/services installed
  (fixes bnc #608164 )
* Wed May  5 2010 lars@linux-schulserver.de
- set default values in init script
* Mon May  3 2010 lars@linux-schulserver.de
- fix file ownership in /etc
- added nrpe manpage from debian
- added adapted patches from Debian:
  + nrpe-more_random.patch (overwrite the buffer with better
    randomness)
  + nrpe-improved_help.patch (list additional commandline options)
  + nrpe-weird_output.patch (null the buffer before using it)
  + nrpe-drop_privileges_before_writing_pidfile.patch (name says all)
- added the following patches to fix compilation warnings:
  + nrpe-return_value.patch
  + nrpe-uninitialized_variable.patch
  + nrpe-unused_variable.patch
* Thu Apr 29 2010 lars@linux-schulserver.de
- use /var/run/nrpe/nrpe.pid for pidfile; nagios can be run as
  different user/group which might cause conflicts
- clean up the init skript and implement automatic movement/
  creation of the pid directory
- package /var/run/nrpe/nrpe.pid as ghost
* Sat Mar  6 2010 chris@computersalat.de
- cleanup subpackages
  o nagios-nrpe is default package and provides NRPE daemon
    obsoletes: client
  o nagios-plugins-nrpe provides the check plugin to be installed
    with the nagios host
    obsoletes: server
- cleanup spec
  o sort TAGS
  o removed/added define
  - nsusr == nrpeusr
  - nsgrp == nrpegrp
  - added cmdgrp
  - redefine _libexecdir
  o added PreReq
  o fix pre{,un}/post{,un} sections
  - no restart_on_update x{,inetd}, cause xinet file is
    installed 'disabled' by default
  - service port is needed with server, not with plugin
  - no restart_on_update nagios when nrpe plugin is update
    there is also no restart_on_update when nagios_plugins
    are updated
  o fix nrpe.cfg
    o PID_File => /var/run/nagios/nrpe.pid
- SOURCE mods
  o reworked patches (Makefile,xinetd)
  o replaced rcnrpe with nrpe.init
  o added README.SuSE
* Wed Dec 23 2009 aj@suse.de
- Use -fno-strict-aliasing to CFLAGS since the code is not clean.
- Own /etc/nagios directory.
- Add _GNU_SOURCE to CFLAGS to get prototype of asprintf.
* Mon Dec  1 2008 lrupp@suse.de
- disable buffersize patch per default: breaks compatibility
- run try-restart only if the service is installed
* Thu Nov 27 2008 lrupp@suse.de
- Added nagios-nrpe-buffersize.patch: support long check output
  of plugins, which is possible since Nagios 3.0
* Mon Oct 13 2008 lrupp@suse.de
- added cron to Should-Start/Should-Stop, so nrpe starts even on
  curious systems
- added nagios-nrpe-SuSEfirewall2
- use --with-log_facility=daemon
* Wed Sep 10 2008 lars@linux-schulserver.de
- disable nrpe in xinetd per default
- use a more stupid way to get the port in etc/services
* Mon Jul 28 2008 lars@linux-schulserver.de
- move the Requires from the main- into the subpackage
* Tue Mar 11 2008 lars@linux-schulserver.de
- update to 2.12:
  + Fix for unterminated multiline plugin (garbage) output
    (Krzysztof Oledzki). Needed for nagios 3.0
- own the docu directory
- added rpmlintrc
* Tue Jan 29 2008 lars@linux-schulserver.de
- Update to 2.11:
  + Added lib64 library paths to configure script for
    64-bit systems (John Maag)
  + Added --with-ssl-lib configure script option
  + Added --with-log-facility option to control syslog logging
    (Ryan Ordway and Brian Seklecki)
* Mon Jan 21 2008 lars@linux-schulserver.de
- start the client automatically
* Wed Jan  9 2008 lars@linux-schulserver.de
- split out the documenation to an extra package
* Thu Dec 27 2007 lars@linux-schulserver.de
- use user nagios and group nagios to run as daemon (client)
- try to add the nrpeport to /etc/services if not done already
* Wed Dec 26 2007 lars@linux-schulserver.de
- back to nagios* again as all pathnames are now identical
* Tue Nov 27 2007 lars@linux-schulserver.de
- rename to nagios3*
- use new libexecdir
* Fri Nov 23 2007 lars@linux-schulserver.de
- require krb5 for suse_version < 1000; otherwise heimdal
* Thu Oct 25 2007 tsieden@suse.de
- Moved PDF docs to docs/ subdirectory, added OpenOffice source document
- A critical result is now returned for child processed that die due to a signal (Klas Lindfors)
- Fixed bug with --with-nrpe-group configure script option (Graham Collinson)
- Fixed bug with check_disk thresholds in sample config file (Patric Wust)
- Added NRPE_PROGRAMVERSION and NRPE_MULTILINESUPPORT environment variables
  for scripts that need to detect NRPE version and capabilities (Gerhard Lausser)
- Added asprintf() support for systems that are missing it (Samba team)
* Mon May 21 2007 tsieden@suse.de
- fix build (Requires libopenssl and openssl for 10.3 and beyond)
* Wed May 16 2007 tsieden@suse.de
- update to version 2.8.1
  * Fixed configure script error with user-specified NRPE group
  * Added support for multiline plugin output (limited to 1KB at the moment) (Matthias Flacke)
  * Changes to sample config files
  * Added ';' as an additional prohibited metachar for command arguments
  * Updated documentation and added easier installation commands
* Mon Mar 12 2007 tsieden@suse.de
- update to version 2.7.1
  * Changed C++ style comment to C style to fix compilation errors on AIX
    (Ryan McGarry)
  * Patches for detection SSL header and library locations
    (Andrew Boyce-Lewis)
  * NRPE daemon will now partially ignore non-fatal configuration file
    errors and attempt to startup (Andrew Boyce-Lewis)
* Tue Jan 30 2007 tsieden@suse.de
- update to version 2.6
  * Added -u option to check_nrpe to return UNKNOWN states on socket
    timeouts (Bjoern Beutel)
  * Added connection_timeout variable to NRPE daemon to catch dead
    client connections (Ton Voon)
  * Added graceful timeout to check_nrpe to ensure connection to
    NRPE daemon is properly closed (Mark Plaksin)
* Sat Jul  1 2006 stark@suse.de
- update to version 2.5.2
  * number of bugfixes
  * Added optional command line prefix
  * Added ability to reload config file with SIGHUP
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 stark@suse.de
- added patch to fix config parser regression
* Mon Jan 23 2006 stark@suse.de
- update to version 2.2
- enabled TCP wrapper support
* Wed Jan 18 2006 stark@suse.de
- added -fstack-protector
- added service handling for update and removal
* Tue Jan 17 2006 stark@suse.de
- added init script (#143288)
- fixed xinet configuration (#143288)
* Tue Nov 18 2003 stark@suse.de
- update to 2.0 final
- don't build as root
* Mon Sep 15 2003 stark@suse.de
- require inet-daemon (#30752)
- use port number in xinet config (#30754)
* Thu Jul 24 2003 stark@suse.de
- update to 2.0b5
* Mon Jul 21 2003 stark@suse.de
- update to 2.0b4
  * minor fixes
* Thu Jun 19 2003 stark@suse.de
- added nagios-plugins to neededforbuild (fixing directory
  ownerships)
* Tue May 20 2003 stark@suse.de
- update to 2.0b3
  * Added support for passing arguments to command
  * NRPE daemon can no longer be run as root user/group
  * Added native SSL support (Derrick Bennett)
* Wed Feb  5 2003 stark@suse.de
- update to 1.8
  * Daemon now closes stdio/out/err properly
  * Makefile changes
  * Mode command line option bug fix in daemon
  * Fixed incorrect command line options in check_nrpe plugin
* Thu Jan 16 2003 stark@suse.de
- added /etc/xinetd.d/nagios-nrpe
- moved nrpe to /usr/bin
* Mon Jan 13 2003 stark@suse.de
- update to 1.7
  * Syntax changes (-H option specifies host name in check_nrpe,
  - c option specifies config file in nrpe)
  * Added command_timeout directive to config file to allow user
    to specify timeout for executing plugins
* Thu Sep 26 2002 stark@suse.de
- initial package
